copynumber: Retrieve copynumber data from cgh objects.

Description Usage Arguments Value Author(s) See Also Examples

Description

These generic functions access the copynumber values of assay data stored in an object derived from the cghRaw-class, cghSeg-class or cghCall-class.

Usage

1
2
3
4
5
6
copynumber(object)
copynumber(object) <- value
segmented(object)
segmented(object) <- value
calls(object)
calls(object) <- value

Arguments

object

Object derived from class cghRaw, cghSeg, or cghCall

value

Matrix with rows representing features and columns samples.

Value

copynumber returns a matrix of copynumber values;

Author(s)

Sjoerd Vosse

See Also

cghRaw-class, cghSeg-class, cghCall-class

Examples

1
2
3
4

Example output

Loading required package: Biobase
Loading required package: BiocGenerics
Loading required package: parallel

Attaching package: ‘BiocGenerics’

The following objects are masked from ‘package:parallel’:

    clusterApply, clusterApplyLB, clusterCall, clusterEvalQ,
    clusterExport, clusterMap, parApply, parCapply, parLapply,
    parLapplyLB, parRapply, parSapply, parSapplyLB

The following objects are masked from ‘package:stats’:

    IQR, mad, sd, var, xtabs

The following objects are masked from ‘package:base’:

    anyDuplicated, append, as.data.frame, basename, cbind, colnames,
    dirname, do.call, duplicated, eval, evalq, Filter, Find, get, grep,
    grepl, intersect, is.unsorted, lapply, Map, mapply, match, mget,
    order, paste, pmax, pmax.int, pmin, pmin.int, Position, rank,
    rbind, Reduce, rownames, sapply, setdiff, sort, table, tapply,
    union, unique, unsplit, which.max, which.min

Welcome to Bioconductor

    Vignettes contain introductory material; view with
    'browseVignettes()'. To cite Bioconductor, see
    'citation("Biobase")', and for packages 'citation("pkgname")'.

Loading required package: marray
Loading required package: limma

Attaching package: ‘limma’

The following object is masked from ‘package:BiocGenerics’:

    plotMA

CGHbase documentation built on Nov. 8, 2020, 5:04 p.m.